# Django Mix

Laravel Mix helper in python representation to easy usage with laravel-mix npm package in Django projects.

## Usage

 ```
<script src="{% mix 'app.js' 'polls/static' %}"></script>
 ```

 The paths are related to webpack.mix.js configuration.
